Module service_clock_skew

Module service_clock_skew 

Interceptor that determines the clock skew between the client and service.

Structs

DisableClockSkewCorrection
When present and true, clock skew correction is disabled.
ServiceClockSkewClassifier
Retry classifier for clock-skew errors.
ServiceClockSkewInterceptor
Interceptor that tracks the clock skew between the client and service, corrects the signing timestamp on retries, and records the skew for retry classification.